# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: groups_roles.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12groups_roles.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"\x8a\x01\n\x16GroupRoleCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12-\n\ngroup_role\x18\x02 \x01(\x0b\x32\r.v1.GroupRoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xc3\x01\n\x17GroupRoleCreateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12-\n\ngroup_role\x18\x02 \x01(\x0b\x32\r.v1.GroupRoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"m\n\x13GroupRoleGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xc9\x01\n\x14GroupRoleGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12-\n\ngroup_role\x18\x02 \x01(\x0b\x32\r.v1.GroupRoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"s\n\x16GroupRoleDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xcf\x01\n\x17GroupRoleDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12-\n\ngroup_role\x18\x03 \x01(\x0b\x32\r.v1.GroupRoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"s\n\x14GroupRoleListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xc1\x01\n\x15GroupRoleListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12/\n\x0cgroups_roles\x18\x02 \x03(\x0b\x32\r.v1.GroupRoleB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xc6\x02\n\tGroupRole\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12!\n\x08group_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12 \n\x07role_id\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x32\n\ngroup_name\x18\x04 \x01(\tB\x1e\xf2\xf8\xb3\x07\x19\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private\x12\x36\n\trole_name\x18\x05 \x01(\tB#\xf2\xf8\xb3\x07\x1e\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private\xd0\xf4\xb3\x07\x01:p\xfa\xf8\xb3\x07k\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07S\xa2\xf3\xb3\x07#tf_examples/group_role_resource.txt\xaa\xf3\xb3\x07&tf_examples/group_role_data_source.txt\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li2\xf4\x03\n\x0bGroupsRoles\x12j\n\x06\x43reate\x12\x1a.v1.GroupRoleCreateRequest\x1a\x1b.v1.GroupRoleCreateResponse\"\'\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x14\xaa\xf3\xb3\x07\x0f/v1/groupsroles\x12\x65\n\x03Get\x12\x17.v1.GroupRoleGetRequest\x1a\x18.v1.GroupRoleGetResponse\"+\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x19\xaa\xf3\xb3\x07\x14/v1/groupsroles/{id}\x12q\n\x06\x44\x65lete\x12\x1a.v1.GroupRoleDeleteRequest\x1a\x1b.v1.GroupRoleDeleteResponse\".\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x19\xaa\xf3\xb3\x07\x14/v1/groupsroles/{id}\x12\x63\n\x04List\x12\x18.v1.GroupRoleListRequest\x1a\x19.v1.GroupRoleListResponse\"&\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x14\xaa\xf3\xb3\x07\x0f/v1/groupsroles\x1a:\xca\xf9\xb3\x07+\xc2\xf9\xb3\x07\tGroupRole\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x03\x63li\xd2\xf9\xb3\x07\ngrouprole-\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42\x7f\n\x19\x63om.strongdm.api.plumbingB\x13GroupsRolesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x08\xa2\x8c\xb4\x07\x03\x63lib\x06proto3')



_GROUPROLECREATEREQUEST = DESCRIPTOR.message_types_by_name['GroupRoleCreateRequest']
_GROUPROLECREATERESPONSE = DESCRIPTOR.message_types_by_name['GroupRoleCreateResponse']
_GROUPROLEGETREQUEST = DESCRIPTOR.message_types_by_name['GroupRoleGetRequest']
_GROUPROLEGETRESPONSE = DESCRIPTOR.message_types_by_name['GroupRoleGetResponse']
_GROUPROLEDELETEREQUEST = DESCRIPTOR.message_types_by_name['GroupRoleDeleteRequest']
_GROUPROLEDELETERESPONSE = DESCRIPTOR.message_types_by_name['GroupRoleDeleteResponse']
_GROUPROLELISTREQUEST = DESCRIPTOR.message_types_by_name['GroupRoleListRequest']
_GROUPROLELISTRESPONSE = DESCRIPTOR.message_types_by_name['GroupRoleListResponse']
_GROUPROLE = DESCRIPTOR.message_types_by_name['GroupRole']
GroupRoleCreateRequest = _reflection.GeneratedProtocolMessageType('GroupRoleCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROLECREATEREQUEST,
  '__module__' : 'groups_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupRoleCreateRequest)
  })
_sym_db.RegisterMessage(GroupRoleCreateRequest)

GroupRoleCreateResponse = _reflection.GeneratedProtocolMessageType('GroupRoleCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROLECREATERESPONSE,
  '__module__' : 'groups_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupRoleCreateResponse)
  })
_sym_db.RegisterMessage(GroupRoleCreateResponse)

GroupRoleGetRequest = _reflection.GeneratedProtocolMessageType('GroupRoleGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROLEGETREQUEST,
  '__module__' : 'groups_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupRoleGetRequest)
  })
_sym_db.RegisterMessage(GroupRoleGetRequest)

GroupRoleGetResponse = _reflection.GeneratedProtocolMessageType('GroupRoleGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROLEGETRESPONSE,
  '__module__' : 'groups_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupRoleGetResponse)
  })
_sym_db.RegisterMessage(GroupRoleGetResponse)

GroupRoleDeleteRequest = _reflection.GeneratedProtocolMessageType('GroupRoleDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROLEDELETEREQUEST,
  '__module__' : 'groups_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupRoleDeleteRequest)
  })
_sym_db.RegisterMessage(GroupRoleDeleteRequest)

GroupRoleDeleteResponse = _reflection.GeneratedProtocolMessageType('GroupRoleDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROLEDELETERESPONSE,
  '__module__' : 'groups_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupRoleDeleteResponse)
  })
_sym_db.RegisterMessage(GroupRoleDeleteResponse)

GroupRoleListRequest = _reflection.GeneratedProtocolMessageType('GroupRoleListRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROLELISTREQUEST,
  '__module__' : 'groups_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupRoleListRequest)
  })
_sym_db.RegisterMessage(GroupRoleListRequest)

GroupRoleListResponse = _reflection.GeneratedProtocolMessageType('GroupRoleListResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROLELISTRESPONSE,
  '__module__' : 'groups_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupRoleListResponse)
  })
_sym_db.RegisterMessage(GroupRoleListResponse)

GroupRole = _reflection.GeneratedProtocolMessageType('GroupRole', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROLE,
  '__module__' : 'groups_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupRole)
  })
_sym_db.RegisterMessage(GroupRole)

_GROUPSROLES = DESCRIPTOR.services_by_name['GroupsRoles']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\023GroupsRolesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\010\242\214\264\007\003cli'
  _GROUPROLECREATEREQUEST.fields_by_name['group_role']._options = None
  _GROUPROLECREATEREQUEST.fields_by_name['group_role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLECREATEREQUEST._options = None
  _GROUPROLECREATEREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPROLECREATERESPONSE.fields_by_name['group_role']._options = None
  _GROUPROLECREATERESPONSE.fields_by_name['group_role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLECREATERESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPROLECREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLECREATERESPONSE._options = None
  _GROUPROLECREATERESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPROLEGETREQUEST.fields_by_name['id']._options = None
  _GROUPROLEGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLEGETREQUEST._options = None
  _GROUPROLEGETREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPROLEGETRESPONSE.fields_by_name['meta']._options = None
  _GROUPROLEGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLEGETRESPONSE.fields_by_name['group_role']._options = None
  _GROUPROLEGETRESPONSE.fields_by_name['group_role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLEGETRESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPROLEGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLEGETRESPONSE._options = None
  _GROUPROLEGETRESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPROLEDELETEREQUEST.fields_by_name['id']._options = None
  _GROUPROLEDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLEDELETEREQUEST._options = None
  _GROUPROLEDELETEREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPROLEDELETERESPONSE.fields_by_name['meta']._options = None
  _GROUPROLEDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLEDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPROLEDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLEDELETERESPONSE.fields_by_name['group_role']._options = None
  _GROUPROLEDELETERESPONSE.fields_by_name['group_role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLEDELETERESPONSE._options = None
  _GROUPROLEDELETERESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPROLELISTREQUEST.fields_by_name['filter']._options = None
  _GROUPROLELISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLELISTREQUEST._options = None
  _GROUPROLELISTREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPROLELISTRESPONSE.fields_by_name['groups_roles']._options = None
  _GROUPROLELISTRESPONSE.fields_by_name['groups_roles']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _GROUPROLELISTRESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPROLELISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLELISTRESPONSE._options = None
  _GROUPROLELISTRESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPROLE.fields_by_name['id']._options = None
  _GROUPROLE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLE.fields_by_name['group_id']._options = None
  _GROUPROLE.fields_by_name['group_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _GROUPROLE.fields_by_name['role_id']._options = None
  _GROUPROLE.fields_by_name['role_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _GROUPROLE.fields_by_name['group_name']._options = None
  _GROUPROLE.fields_by_name['group_name']._serialized_options = b'\362\370\263\007\031\260\363\263\007\001\230\364\263\007\001\262\364\263\007\ngo_private'
  _GROUPROLE.fields_by_name['role_name']._options = None
  _GROUPROLE.fields_by_name['role_name']._serialized_options = b'\362\370\263\007\036\260\363\263\007\001\230\364\263\007\001\262\364\263\007\ngo_private\320\364\263\007\001'
  _GROUPROLE._options = None
  _GROUPROLE._serialized_options = b'\372\370\263\007k\250\363\263\007\001\302\363\263\007S\242\363\263\007#tf_examples/group_role_resource.txt\252\363\263\007&tf_examples/group_role_data_source.txt\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPSROLES._options = None
  _GROUPSROLES._serialized_options = b'\312\371\263\007+\302\371\263\007\tGroupRole\312\371\263\007\001*\312\371\263\007\003cli\322\371\263\007\ngrouprole-\312\371\263\007\005\350\371\263\007\001'
  _GROUPSROLES.methods_by_name['Create']._options = None
  _GROUPSROLES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\024\252\363\263\007\017/v1/groupsroles'
  _GROUPSROLES.methods_by_name['Get']._options = None
  _GROUPSROLES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\031\252\363\263\007\024/v1/groupsroles/{id}'
  _GROUPSROLES.methods_by_name['Delete']._options = None
  _GROUPSROLES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\031\252\363\263\007\024/v1/groupsroles/{id}'
  _GROUPSROLES.methods_by_name['List']._options = None
  _GROUPSROLES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\024\252\363\263\007\017/v1/groupsroles'
  _GROUPROLECREATEREQUEST._serialized_start=54
  _GROUPROLECREATEREQUEST._serialized_end=192
  _GROUPROLECREATERESPONSE._serialized_start=195
  _GROUPROLECREATERESPONSE._serialized_end=390
  _GROUPROLEGETREQUEST._serialized_start=392
  _GROUPROLEGETREQUEST._serialized_end=501
  _GROUPROLEGETRESPONSE._serialized_start=504
  _GROUPROLEGETRESPONSE._serialized_end=705
  _GROUPROLEDELETEREQUEST._serialized_start=707
  _GROUPROLEDELETEREQUEST._serialized_end=822
  _GROUPROLEDELETERESPONSE._serialized_start=825
  _GROUPROLEDELETERESPONSE._serialized_end=1032
  _GROUPROLELISTREQUEST._serialized_start=1034
  _GROUPROLELISTREQUEST._serialized_end=1149
  _GROUPROLELISTRESPONSE._serialized_start=1152
  _GROUPROLELISTRESPONSE._serialized_end=1345
  _GROUPROLE._serialized_start=1348
  _GROUPROLE._serialized_end=1674
  _GROUPSROLES._serialized_start=1677
  _GROUPSROLES._serialized_end=2177
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: control_panel.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63ontrol_panel.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"L\n$ControlPanelGetSSHCAPublicKeyRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\"\xdf\x01\n%ControlPanelGetSSHCAPublicKeyResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\npublic_key\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"L\n$ControlPanelGetRDPCAPublicKeyRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\"\xdf\x01\n%ControlPanelGetRDPCAPublicKeyResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\npublic_key\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"_\n\x1c\x43ontrolPanelVerifyJWTRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x19\n\x05token\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd2\x01\n\x1d\x43ontrolPanelVerifyJWTResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x19\n\x05valid\x18\x02 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x32\xd0\x03\n\x0c\x43ontrolPanel\x12\x99\x01\n\x11GetSSHCAPublicKey\x12(.v1.ControlPanelGetSSHCAPublicKeyRequest\x1a).v1.ControlPanelGetSSHCAPublicKeyResponse\"/\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1d\xaa\xf3\xb3\x07\x18/v1/control-panel/ssh/ca\x12\x99\x01\n\x11GetRDPCAPublicKey\x12(.v1.ControlPanelGetRDPCAPublicKeyRequest\x1a).v1.ControlPanelGetRDPCAPublicKeyResponse\"/\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1d\xaa\xf3\xb3\x07\x18/v1/control-panel/rdp/ca\x12\x87\x01\n\tVerifyJWT\x12 .v1.ControlPanelVerifyJWTRequest\x1a!.v1.ControlPanelVerifyJWTResponse\"5\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\"\xaa\xf3\xb3\x07\x1d/v1/control-panel/http/verifyBh\n\x19\x63om.strongdm.api.plumbingB\x14\x43ontrolPanelPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_CONTROLPANELGETSSHCAPUBLICKEYREQUEST = DESCRIPTOR.message_types_by_name['ControlPanelGetSSHCAPublicKeyRequest']
_CONTROLPANELGETSSHCAPUBLICKEYRESPONSE = DESCRIPTOR.message_types_by_name['ControlPanelGetSSHCAPublicKeyResponse']
_CONTROLPANELGETRDPCAPUBLICKEYREQUEST = DESCRIPTOR.message_types_by_name['ControlPanelGetRDPCAPublicKeyRequest']
_CONTROLPANELGETRDPCAPUBLICKEYRESPONSE = DESCRIPTOR.message_types_by_name['ControlPanelGetRDPCAPublicKeyResponse']
_CONTROLPANELVERIFYJWTREQUEST = DESCRIPTOR.message_types_by_name['ControlPanelVerifyJWTRequest']
_CONTROLPANELVERIFYJWTRESPONSE = DESCRIPTOR.message_types_by_name['ControlPanelVerifyJWTResponse']
ControlPanelGetSSHCAPublicKeyRequest = _reflection.GeneratedProtocolMessageType('ControlPanelGetSSHCAPublicKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLPANELGETSSHCAPUBLICKEYREQUEST,
  '__module__' : 'control_panel_pb2'
  # @@protoc_insertion_point(class_scope:v1.ControlPanelGetSSHCAPublicKeyRequest)
  })
_sym_db.RegisterMessage(ControlPanelGetSSHCAPublicKeyRequest)

ControlPanelGetSSHCAPublicKeyResponse = _reflection.GeneratedProtocolMessageType('ControlPanelGetSSHCAPublicKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLPANELGETSSHCAPUBLICKEYRESPONSE,
  '__module__' : 'control_panel_pb2'
  # @@protoc_insertion_point(class_scope:v1.ControlPanelGetSSHCAPublicKeyResponse)
  })
_sym_db.RegisterMessage(ControlPanelGetSSHCAPublicKeyResponse)

ControlPanelGetRDPCAPublicKeyRequest = _reflection.GeneratedProtocolMessageType('ControlPanelGetRDPCAPublicKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLPANELGETRDPCAPUBLICKEYREQUEST,
  '__module__' : 'control_panel_pb2'
  # @@protoc_insertion_point(class_scope:v1.ControlPanelGetRDPCAPublicKeyRequest)
  })
_sym_db.RegisterMessage(ControlPanelGetRDPCAPublicKeyRequest)

ControlPanelGetRDPCAPublicKeyResponse = _reflection.GeneratedProtocolMessageType('ControlPanelGetRDPCAPublicKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLPANELGETRDPCAPUBLICKEYRESPONSE,
  '__module__' : 'control_panel_pb2'
  # @@protoc_insertion_point(class_scope:v1.ControlPanelGetRDPCAPublicKeyResponse)
  })
_sym_db.RegisterMessage(ControlPanelGetRDPCAPublicKeyResponse)

ControlPanelVerifyJWTRequest = _reflection.GeneratedProtocolMessageType('ControlPanelVerifyJWTRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLPANELVERIFYJWTREQUEST,
  '__module__' : 'control_panel_pb2'
  # @@protoc_insertion_point(class_scope:v1.ControlPanelVerifyJWTRequest)
  })
_sym_db.RegisterMessage(ControlPanelVerifyJWTRequest)

ControlPanelVerifyJWTResponse = _reflection.GeneratedProtocolMessageType('ControlPanelVerifyJWTResponse', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLPANELVERIFYJWTRESPONSE,
  '__module__' : 'control_panel_pb2'
  # @@protoc_insertion_point(class_scope:v1.ControlPanelVerifyJWTResponse)
  })
_sym_db.RegisterMessage(ControlPanelVerifyJWTResponse)

_CONTROLPANEL = DESCRIPTOR.services_by_name['ControlPanel']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\024ControlPanelPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _CONTROLPANELGETSSHCAPUBLICKEYRESPONSE.fields_by_name['meta']._options = None
  _CONTROLPANELGETSSHCAPUBLICKEYRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONTROLPANELGETSSHCAPUBLICKEYRESPONSE.fields_by_name['public_key']._options = None
  _CONTROLPANELGETSSHCAPUBLICKEYRESPONSE.fields_by_name['public_key']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONTROLPANELGETSSHCAPUBLICKEYRESPONSE.fields_by_name['rate_limit']._options = None
  _CONTROLPANELGETSSHCAPUBLICKEYRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _CONTROLPANELGETSSHCAPUBLICKEYRESPONSE._options = None
  _CONTROLPANELGETSSHCAPUBLICKEYRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _CONTROLPANELGETRDPCAPUBLICKEYRESPONSE.fields_by_name['meta']._options = None
  _CONTROLPANELGETRDPCAPUBLICKEYRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONTROLPANELGETRDPCAPUBLICKEYRESPONSE.fields_by_name['public_key']._options = None
  _CONTROLPANELGETRDPCAPUBLICKEYRESPONSE.fields_by_name['public_key']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONTROLPANELGETRDPCAPUBLICKEYRESPONSE.fields_by_name['rate_limit']._options = None
  _CONTROLPANELGETRDPCAPUBLICKEYRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _CONTROLPANELGETRDPCAPUBLICKEYRESPONSE._options = None
  _CONTROLPANELGETRDPCAPUBLICKEYRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _CONTROLPANELVERIFYJWTREQUEST.fields_by_name['token']._options = None
  _CONTROLPANELVERIFYJWTREQUEST.fields_by_name['token']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONTROLPANELVERIFYJWTRESPONSE.fields_by_name['meta']._options = None
  _CONTROLPANELVERIFYJWTRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONTROLPANELVERIFYJWTRESPONSE.fields_by_name['valid']._options = None
  _CONTROLPANELVERIFYJWTRESPONSE.fields_by_name['valid']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONTROLPANELVERIFYJWTRESPONSE.fields_by_name['rate_limit']._options = None
  _CONTROLPANELVERIFYJWTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _CONTROLPANELVERIFYJWTRESPONSE._options = None
  _CONTROLPANELVERIFYJWTRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _CONTROLPANEL.methods_by_name['GetSSHCAPublicKey']._options = None
  _CONTROLPANEL.methods_by_name['GetSSHCAPublicKey']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\035\252\363\263\007\030/v1/control-panel/ssh/ca'
  _CONTROLPANEL.methods_by_name['GetRDPCAPublicKey']._options = None
  _CONTROLPANEL.methods_by_name['GetRDPCAPublicKey']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\035\252\363\263\007\030/v1/control-panel/rdp/ca'
  _CONTROLPANEL.methods_by_name['VerifyJWT']._options = None
  _CONTROLPANEL.methods_by_name['VerifyJWT']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\"\252\363\263\007\035/v1/control-panel/http/verify'
  _CONTROLPANELGETSSHCAPUBLICKEYREQUEST._serialized_start=54
  _CONTROLPANELGETSSHCAPUBLICKEYREQUEST._serialized_end=130
  _CONTROLPANELGETSSHCAPUBLICKEYRESPONSE._serialized_start=133
  _CONTROLPANELGETSSHCAPUBLICKEYRESPONSE._serialized_end=356
  _CONTROLPANELGETRDPCAPUBLICKEYREQUEST._serialized_start=358
  _CONTROLPANELGETRDPCAPUBLICKEYREQUEST._serialized_end=434
  _CONTROLPANELGETRDPCAPUBLICKEYRESPONSE._serialized_start=437
  _CONTROLPANELGETRDPCAPUBLICKEYRESPONSE._serialized_end=660
  _CONTROLPANELVERIFYJWTREQUEST._serialized_start=662
  _CONTROLPANELVERIFYJWTREQUEST._serialized_end=757
  _CONTROLPANELVERIFYJWTRESPONSE._serialized_start=760
  _CONTROLPANELVERIFYJWTRESPONSE._serialized_end=970
  _CONTROLPANEL._serialized_start=973
  _CONTROLPANEL._serialized_end=1437
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: secret_engine_policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1asecret_engine_policy.proto\x12\x02v1\x1a\roptions.proto\"\xf7\x01\n\x1aSecretEnginePasswordPolicy\x12\x1a\n\x06length\x18\x01 \x01(\rB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12&\n\x12\x65xclude_upper_case\x18\x02 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\nnum_digits\x18\x03 \x01(\rB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1f\n\x0bnum_symbols\x18\x04 \x01(\rB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12 \n\x0c\x61llow_repeat\x18\x05 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12&\n\x12\x65xclude_characters\x18\x06 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"e\n\x12SecretEnginePolicy\x12\x43\n\x0fpassword_policy\x18\x01 \x01(\x0b\x32\x1e.v1.SecretEnginePasswordPolicyB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x42n\n\x19\x63om.strongdm.api.plumbingB\x1aSecretEnginePolicyPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_SECRETENGINEPASSWORDPOLICY = DESCRIPTOR.message_types_by_name['SecretEnginePasswordPolicy']
_SECRETENGINEPOLICY = DESCRIPTOR.message_types_by_name['SecretEnginePolicy']
SecretEnginePasswordPolicy = _reflection.GeneratedProtocolMessageType('SecretEnginePasswordPolicy', (_message.Message,), {
  'DESCRIPTOR' : _SECRETENGINEPASSWORDPOLICY,
  '__module__' : 'secret_engine_policy_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretEnginePasswordPolicy)
  })
_sym_db.RegisterMessage(SecretEnginePasswordPolicy)

SecretEnginePolicy = _reflection.GeneratedProtocolMessageType('SecretEnginePolicy', (_message.Message,), {
  'DESCRIPTOR' : _SECRETENGINEPOLICY,
  '__module__' : 'secret_engine_policy_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretEnginePolicy)
  })
_sym_db.RegisterMessage(SecretEnginePolicy)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\032SecretEnginePolicyPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _SECRETENGINEPASSWORDPOLICY.fields_by_name['length']._options = None
  _SECRETENGINEPASSWORDPOLICY.fields_by_name['length']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINEPASSWORDPOLICY.fields_by_name['exclude_upper_case']._options = None
  _SECRETENGINEPASSWORDPOLICY.fields_by_name['exclude_upper_case']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINEPASSWORDPOLICY.fields_by_name['num_digits']._options = None
  _SECRETENGINEPASSWORDPOLICY.fields_by_name['num_digits']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINEPASSWORDPOLICY.fields_by_name['num_symbols']._options = None
  _SECRETENGINEPASSWORDPOLICY.fields_by_name['num_symbols']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINEPASSWORDPOLICY.fields_by_name['allow_repeat']._options = None
  _SECRETENGINEPASSWORDPOLICY.fields_by_name['allow_repeat']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINEPASSWORDPOLICY.fields_by_name['exclude_characters']._options = None
  _SECRETENGINEPASSWORDPOLICY.fields_by_name['exclude_characters']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINEPASSWORDPOLICY._options = None
  _SECRETENGINEPASSWORDPOLICY._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _SECRETENGINEPOLICY.fields_by_name['password_policy']._options = None
  _SECRETENGINEPOLICY.fields_by_name['password_policy']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINEPOLICY._options = None
  _SECRETENGINEPOLICY._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _SECRETENGINEPASSWORDPOLICY._serialized_start=50
  _SECRETENGINEPASSWORDPOLICY._serialized_end=297
  _SECRETENGINEPOLICY._serialized_start=299
  _SECRETENGINEPOLICY._serialized_end=400
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spec.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nspec.proto\x12\x02v1\x1a\roptions.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"<\n\x12\x41lreadyExistsError\x12\x1a\n\x06\x65ntity\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x06\"7\n\rNotFoundError\x12\x1a\n\x06\x65ntity\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x05\"\x1d\n\x0f\x42\x61\x64RequestError:\n\xfa\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x03\"!\n\x13\x41uthenticationError:\n\xfa\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x10\"\x1d\n\x0fPermissionError:\n\xfa\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x07\"\x1b\n\rInternalError:\n\xfa\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\r\"u\n\x0eRateLimitError\x12W\n\nrate_limit\x18\x01 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x08\"G\n\x15\x43reateRequestMetadata\x12.\n\x0c\x66ulfillments\x18\x01 \x01(\x0b\x32\x18.v1.FulfillmentsMetadata\"$\n\x16\x43reateResponseMetadata:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"u\n\x12GetRequestMetadata\x12/\n\x0bsnapshot_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\x0c\x66ulfillments\x18\x02 \x01(\x0b\x32\x18.v1.FulfillmentsMetadata\"!\n\x13GetResponseMetadata:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"G\n\x15UpdateRequestMetadata\x12.\n\x0c\x66ulfillments\x18\x01 \x01(\x0b\x32\x18.v1.FulfillmentsMetadata\"$\n\x16UpdateResponseMetadata:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"G\n\x15\x44\x65leteRequestMetadata\x12.\n\x0c\x66ulfillments\x18\x01 \x01(\x0b\x32\x18.v1.FulfillmentsMetadata\"$\n\x16\x44\x65leteResponseMetadata:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xb5\x01\n\x13ListRequestMetadata\x12\x0e\n\x06\x63ursor\x18\x01 \x01(\t\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x10\n\x08order_by\x18\x04 \x01(\t\x12/\n\x0bsnapshot_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\x0c\x66ulfillments\x18\x06 \x01(\x0b\x32\x18.v1.FulfillmentsMetadata\">\n\x14ListResponseMetadata\x12\x13\n\x0bnext_cursor\x18\x01 \x01(\t\x12\x11\n\x05total\x18\x02 \x01(\x05\x42\x02\x18\x01\"\xaf\x01\n\x11RateLimitMetadata\x12\x19\n\x05limit\x18\x01 \x01(\x03\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\tremaining\x18\x02 \x01(\x03\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x38\n\x08reset_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1a\n\x06\x62ucket\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"H\n\x16GenericRequestMetadata\x12.\n\x0c\x66ulfillments\x18\x01 \x01(\x0b\x32\x18.v1.FulfillmentsMetadata\"%\n\x17GenericResponseMetadata:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"=\n\x14RequirementsMetadata\x12%\n\x0crequirements\x18\x01 \x03(\x0b\x32\x0f.v1.Requirement\"=\n\x14\x46ulfillmentsMetadata\x12%\n\x0c\x66ulfillments\x18\x01 \x03(\x0b\x32\x0f.v1.Fulfillment\"0\n\x03MFA\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x17\n\x0fmethods_enabled\x18\x02 \x03(\t\"@\n\x0bRequirement\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x14\n\x03MFA\x18\x03 \x01(\x0b\x32\x07.v1.MFA\"B\n\x0b\x46ulfillment\x12$\n\x0brequirement\x18\x01 \x01(\x0b\x32\x0f.v1.Requirement\x12\r\n\x05value\x18\x02 \x01(\tBR\n\x19\x63om.strongdm.api.plumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_ALREADYEXISTSERROR = DESCRIPTOR.message_types_by_name['AlreadyExistsError']
_NOTFOUNDERROR = DESCRIPTOR.message_types_by_name['NotFoundError']
_BADREQUESTERROR = DESCRIPTOR.message_types_by_name['BadRequestError']
_AUTHENTICATIONERROR = DESCRIPTOR.message_types_by_name['AuthenticationError']
_PERMISSIONERROR = DESCRIPTOR.message_types_by_name['PermissionError']
_INTERNALERROR = DESCRIPTOR.message_types_by_name['InternalError']
_RATELIMITERROR = DESCRIPTOR.message_types_by_name['RateLimitError']
_CREATEREQUESTMETADATA = DESCRIPTOR.message_types_by_name['CreateRequestMetadata']
_CREATERESPONSEMETADATA = DESCRIPTOR.message_types_by_name['CreateResponseMetadata']
_GETREQUESTMETADATA = DESCRIPTOR.message_types_by_name['GetRequestMetadata']
_GETRESPONSEMETADATA = DESCRIPTOR.message_types_by_name['GetResponseMetadata']
_UPDATEREQUESTMETADATA = DESCRIPTOR.message_types_by_name['UpdateRequestMetadata']
_UPDATERESPONSEMETADATA = DESCRIPTOR.message_types_by_name['UpdateResponseMetadata']
_DELETEREQUESTMETADATA = DESCRIPTOR.message_types_by_name['DeleteRequestMetadata']
_DELETERESPONSEMETADATA = DESCRIPTOR.message_types_by_name['DeleteResponseMetadata']
_LISTREQUESTMETADATA = DESCRIPTOR.message_types_by_name['ListRequestMetadata']
_LISTRESPONSEMETADATA = DESCRIPTOR.message_types_by_name['ListResponseMetadata']
_RATELIMITMETADATA = DESCRIPTOR.message_types_by_name['RateLimitMetadata']
_GENERICREQUESTMETADATA = DESCRIPTOR.message_types_by_name['GenericRequestMetadata']
_GENERICRESPONSEMETADATA = DESCRIPTOR.message_types_by_name['GenericResponseMetadata']
_REQUIREMENTSMETADATA = DESCRIPTOR.message_types_by_name['RequirementsMetadata']
_FULFILLMENTSMETADATA = DESCRIPTOR.message_types_by_name['FulfillmentsMetadata']
_MFA = DESCRIPTOR.message_types_by_name['MFA']
_REQUIREMENT = DESCRIPTOR.message_types_by_name['Requirement']
_FULFILLMENT = DESCRIPTOR.message_types_by_name['Fulfillment']
AlreadyExistsError = _reflection.GeneratedProtocolMessageType('AlreadyExistsError', (_message.Message,), {
  'DESCRIPTOR' : _ALREADYEXISTSERROR,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.AlreadyExistsError)
  })
_sym_db.RegisterMessage(AlreadyExistsError)

NotFoundError = _reflection.GeneratedProtocolMessageType('NotFoundError', (_message.Message,), {
  'DESCRIPTOR' : _NOTFOUNDERROR,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.NotFoundError)
  })
_sym_db.RegisterMessage(NotFoundError)

BadRequestError = _reflection.GeneratedProtocolMessageType('BadRequestError', (_message.Message,), {
  'DESCRIPTOR' : _BADREQUESTERROR,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.BadRequestError)
  })
_sym_db.RegisterMessage(BadRequestError)

AuthenticationError = _reflection.GeneratedProtocolMessageType('AuthenticationError', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATIONERROR,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.AuthenticationError)
  })
_sym_db.RegisterMessage(AuthenticationError)

PermissionError = _reflection.GeneratedProtocolMessageType('PermissionError', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSIONERROR,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.PermissionError)
  })
_sym_db.RegisterMessage(PermissionError)

InternalError = _reflection.GeneratedProtocolMessageType('InternalError', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALERROR,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.InternalError)
  })
_sym_db.RegisterMessage(InternalError)

RateLimitError = _reflection.GeneratedProtocolMessageType('RateLimitError', (_message.Message,), {
  'DESCRIPTOR' : _RATELIMITERROR,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.RateLimitError)
  })
_sym_db.RegisterMessage(RateLimitError)

CreateRequestMetadata = _reflection.GeneratedProtocolMessageType('CreateRequestMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREQUESTMETADATA,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.CreateRequestMetadata)
  })
_sym_db.RegisterMessage(CreateRequestMetadata)

CreateResponseMetadata = _reflection.GeneratedProtocolMessageType('CreateResponseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATERESPONSEMETADATA,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.CreateResponseMetadata)
  })
_sym_db.RegisterMessage(CreateResponseMetadata)

GetRequestMetadata = _reflection.GeneratedProtocolMessageType('GetRequestMetadata', (_message.Message,), {
  'DESCRIPTOR' : _GETREQUESTMETADATA,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.GetRequestMetadata)
  })
_sym_db.RegisterMessage(GetRequestMetadata)

GetResponseMetadata = _reflection.GeneratedProtocolMessageType('GetResponseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _GETRESPONSEMETADATA,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.GetResponseMetadata)
  })
_sym_db.RegisterMessage(GetResponseMetadata)

UpdateRequestMetadata = _reflection.GeneratedProtocolMessageType('UpdateRequestMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREQUESTMETADATA,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.UpdateRequestMetadata)
  })
_sym_db.RegisterMessage(UpdateRequestMetadata)

UpdateResponseMetadata = _reflection.GeneratedProtocolMessageType('UpdateResponseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERESPONSEMETADATA,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.UpdateResponseMetadata)
  })
_sym_db.RegisterMessage(UpdateResponseMetadata)

DeleteRequestMetadata = _reflection.GeneratedProtocolMessageType('DeleteRequestMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREQUESTMETADATA,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.DeleteRequestMetadata)
  })
_sym_db.RegisterMessage(DeleteRequestMetadata)

DeleteResponseMetadata = _reflection.GeneratedProtocolMessageType('DeleteResponseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETERESPONSEMETADATA,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.DeleteResponseMetadata)
  })
_sym_db.RegisterMessage(DeleteResponseMetadata)

ListRequestMetadata = _reflection.GeneratedProtocolMessageType('ListRequestMetadata', (_message.Message,), {
  'DESCRIPTOR' : _LISTREQUESTMETADATA,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.ListRequestMetadata)
  })
_sym_db.RegisterMessage(ListRequestMetadata)

ListResponseMetadata = _reflection.GeneratedProtocolMessageType('ListResponseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _LISTRESPONSEMETADATA,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.ListResponseMetadata)
  })
_sym_db.RegisterMessage(ListResponseMetadata)

RateLimitMetadata = _reflection.GeneratedProtocolMessageType('RateLimitMetadata', (_message.Message,), {
  'DESCRIPTOR' : _RATELIMITMETADATA,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.RateLimitMetadata)
  })
_sym_db.RegisterMessage(RateLimitMetadata)

GenericRequestMetadata = _reflection.GeneratedProtocolMessageType('GenericRequestMetadata', (_message.Message,), {
  'DESCRIPTOR' : _GENERICREQUESTMETADATA,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.GenericRequestMetadata)
  })
_sym_db.RegisterMessage(GenericRequestMetadata)

GenericResponseMetadata = _reflection.GeneratedProtocolMessageType('GenericResponseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _GENERICRESPONSEMETADATA,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.GenericResponseMetadata)
  })
_sym_db.RegisterMessage(GenericResponseMetadata)

RequirementsMetadata = _reflection.GeneratedProtocolMessageType('RequirementsMetadata', (_message.Message,), {
  'DESCRIPTOR' : _REQUIREMENTSMETADATA,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.RequirementsMetadata)
  })
_sym_db.RegisterMessage(RequirementsMetadata)

FulfillmentsMetadata = _reflection.GeneratedProtocolMessageType('FulfillmentsMetadata', (_message.Message,), {
  'DESCRIPTOR' : _FULFILLMENTSMETADATA,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.FulfillmentsMetadata)
  })
_sym_db.RegisterMessage(FulfillmentsMetadata)

MFA = _reflection.GeneratedProtocolMessageType('MFA', (_message.Message,), {
  'DESCRIPTOR' : _MFA,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.MFA)
  })
_sym_db.RegisterMessage(MFA)

Requirement = _reflection.GeneratedProtocolMessageType('Requirement', (_message.Message,), {
  'DESCRIPTOR' : _REQUIREMENT,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.Requirement)
  })
_sym_db.RegisterMessage(Requirement)

Fulfillment = _reflection.GeneratedProtocolMessageType('Fulfillment', (_message.Message,), {
  'DESCRIPTOR' : _FULFILLMENT,
  '__module__' : 'spec_pb2'
  # @@protoc_insertion_point(class_scope:v1.Fulfillment)
  })
_sym_db.RegisterMessage(Fulfillment)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _ALREADYEXISTSERROR.fields_by_name['entity']._options = None
  _ALREADYEXISTSERROR.fields_by_name['entity']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ALREADYEXISTSERROR._options = None
  _ALREADYEXISTSERROR._serialized_options = b'\372\370\263\007\005\260\363\263\007\006'
  _NOTFOUNDERROR.fields_by_name['entity']._options = None
  _NOTFOUNDERROR.fields_by_name['entity']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NOTFOUNDERROR._options = None
  _NOTFOUNDERROR._serialized_options = b'\372\370\263\007\005\260\363\263\007\005'
  _BADREQUESTERROR._options = None
  _BADREQUESTERROR._serialized_options = b'\372\370\263\007\005\260\363\263\007\003'
  _AUTHENTICATIONERROR._options = None
  _AUTHENTICATIONERROR._serialized_options = b'\372\370\263\007\005\260\363\263\007\020'
  _PERMISSIONERROR._options = None
  _PERMISSIONERROR._serialized_options = b'\372\370\263\007\005\260\363\263\007\007'
  _INTERNALERROR._options = None
  _INTERNALERROR._serialized_options = b'\372\370\263\007\005\260\363\263\007\r'
  _RATELIMITERROR.fields_by_name['rate_limit']._options = None
  _RATELIMITERROR.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _RATELIMITERROR._options = None
  _RATELIMITERROR._serialized_options = b'\372\370\263\007\005\260\363\263\007\010'
  _CREATERESPONSEMETADATA._options = None
  _CREATERESPONSEMETADATA._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _GETRESPONSEMETADATA._options = None
  _GETRESPONSEMETADATA._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _UPDATERESPONSEMETADATA._options = None
  _UPDATERESPONSEMETADATA._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _DELETERESPONSEMETADATA._options = None
  _DELETERESPONSEMETADATA._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _LISTRESPONSEMETADATA.fields_by_name['total']._options = None
  _LISTRESPONSEMETADATA.fields_by_name['total']._serialized_options = b'\030\001'
  _RATELIMITMETADATA.fields_by_name['limit']._options = None
  _RATELIMITMETADATA.fields_by_name['limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RATELIMITMETADATA.fields_by_name['remaining']._options = None
  _RATELIMITMETADATA.fields_by_name['remaining']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RATELIMITMETADATA.fields_by_name['reset_at']._options = None
  _RATELIMITMETADATA.fields_by_name['reset_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RATELIMITMETADATA.fields_by_name['bucket']._options = None
  _RATELIMITMETADATA.fields_by_name['bucket']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RATELIMITMETADATA._options = None
  _RATELIMITMETADATA._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _GENERICRESPONSEMETADATA._options = None
  _GENERICRESPONSEMETADATA._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ALREADYEXISTSERROR._serialized_start=66
  _ALREADYEXISTSERROR._serialized_end=126
  _NOTFOUNDERROR._serialized_start=128
  _NOTFOUNDERROR._serialized_end=183
  _BADREQUESTERROR._serialized_start=185
  _BADREQUESTERROR._serialized_end=214
  _AUTHENTICATIONERROR._serialized_start=216
  _AUTHENTICATIONERROR._serialized_end=249
  _PERMISSIONERROR._serialized_start=251
  _PERMISSIONERROR._serialized_end=280
  _INTERNALERROR._serialized_start=282
  _INTERNALERROR._serialized_end=309
  _RATELIMITERROR._serialized_start=311
  _RATELIMITERROR._serialized_end=428
  _CREATEREQUESTMETADATA._serialized_start=430
  _CREATEREQUESTMETADATA._serialized_end=501
  _CREATERESPONSEMETADATA._serialized_start=503
  _CREATERESPONSEMETADATA._serialized_end=539
  _GETREQUESTMETADATA._serialized_start=541
  _GETREQUESTMETADATA._serialized_end=658
  _GETRESPONSEMETADATA._serialized_start=660
  _GETRESPONSEMETADATA._serialized_end=693
  _UPDATEREQUESTMETADATA._serialized_start=695
  _UPDATEREQUESTMETADATA._serialized_end=766
  _UPDATERESPONSEMETADATA._serialized_start=768
  _UPDATERESPONSEMETADATA._serialized_end=804
  _DELETEREQUESTMETADATA._serialized_start=806
  _DELETEREQUESTMETADATA._serialized_end=877
  _DELETERESPONSEMETADATA._serialized_start=879
  _DELETERESPONSEMETADATA._serialized_end=915
  _LISTREQUESTMETADATA._serialized_start=918
  _LISTREQUESTMETADATA._serialized_end=1099
  _LISTRESPONSEMETADATA._serialized_start=1101
  _LISTRESPONSEMETADATA._serialized_end=1163
  _RATELIMITMETADATA._serialized_start=1166
  _RATELIMITMETADATA._serialized_end=1341
  _GENERICREQUESTMETADATA._serialized_start=1343
  _GENERICREQUESTMETADATA._serialized_end=1415
  _GENERICRESPONSEMETADATA._serialized_start=1417
  _GENERICRESPONSEMETADATA._serialized_end=1454
  _REQUIREMENTSMETADATA._serialized_start=1456
  _REQUIREMENTSMETADATA._serialized_end=1517
  _FULFILLMENTSMETADATA._serialized_start=1519
  _FULFILLMENTSMETADATA._serialized_end=1580
  _MFA._serialized_start=1582
  _MFA._serialized_end=1630
  _REQUIREMENT._serialized_start=1632
  _REQUIREMENT._serialized_end=1696
  _FULFILLMENT._serialized_start=1698
  _FULFILLMENT._serialized_end=1764
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workflows.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fworkflows.proto\x12\x02v1\x1a\x1egoogle/protobuf/duration.proto\x1a\roptions.proto\x1a\nspec.proto\"l\n\x15WorkflowCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12*\n\x08workflow\x18\x02 \x01(\x0b\x32\x0c.v1.WorkflowB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd3\x01\n\x16WorkflowCreateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12*\n\x08workflow\x18\x02 \x01(\x0b\x32\x0c.v1.WorkflowB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"R\n\x12WorkflowGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd9\x01\n\x13WorkflowGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12*\n\x08workflow\x18\x02 \x01(\x0b\x32\x0c.v1.WorkflowB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"l\n\x15WorkflowUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12*\n\x08workflow\x18\x02 \x01(\x0b\x32\x0c.v1.WorkflowB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd3\x01\n\x16WorkflowUpdateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadata\x12*\n\x08workflow\x18\x02 \x01(\x0b\x32\x0c.v1.WorkflowB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"X\n\x15WorkflowDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xbf\x01\n\x16WorkflowDeleteResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"X\n\x13WorkflowListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd0\x01\n\x14WorkflowListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12+\n\tworkflows\x18\x02 \x03(\x0b\x32\x0c.v1.WorkflowB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x91\x06\n\x08Workflow\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1f\n\x06weight\x18\x04 \x01(\x03\x42\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xd0\xf4\xb3\x07\x01\x12 \n\nauto_grant\x18\x05 \x01(\x08\x42\x0c\x18\x01\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1b\n\x07\x65nabled\x18\x06 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x32\n\x0frequires_reason\x18\x07 \x01(\x08\x42\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private\x12J\n\x1b\x61\x63\x63\x65ss_request_max_duration\x18\n \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12L\n\x1d\x61\x63\x63\x65ss_request_fixed_duration\x18\x0b \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\xf2\x01\n\x0c\x61\x63\x63\x65ss_rules\x18\x08 \x01(\tB\xdb\x01\xf2\xf8\xb3\x07\xd5\x01\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\xa9\x01\xea\xf3\xb3\x07\x0c\x61\x63\x63\x65ss_rules\xf2\xf3\xb3\x07\x11\n\x02go\x12\x0b\x41\x63\x63\x65ssRules\xf2\xf3\xb3\x07\x19\n\ngo_private\x12\x0b\x41\x63\x63\x65ssRules\xf2\xf3\xb3\x07\x1b\n\x0cgo_terraform\x12\x0b\x41\x63\x63\x65ssRules\xf2\xf3\xb3\x07\x18\n\x04java\x12\x10List<AccessRule>\xf2\xf3\xb3\x07\"\n\x0cjson_gateway\x12\x12models.AccessRules\xba\xf4\xb3\x07\x17\x61\x63\x63\x65ssRulesDiffSuppress\xd0\xf4\xb3\x07\x01\x12$\n\x10\x61pproval_flow_id\x18\t \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:d\xfa\xf8\xb3\x07_\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07O\xa2\xf3\xb3\x07!tf_examples/workflow_resource.txt\xaa\xf3\xb3\x07$tf_examples/workflow_data_source.txt\xd2\xf3\xb3\x07\x01*2\xb2\x04\n\tWorkflows\x12\x66\n\x06\x43reate\x12\x19.v1.WorkflowCreateRequest\x1a\x1a.v1.WorkflowCreateResponse\"%\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x12\xaa\xf3\xb3\x07\r/v1/workflows\x12`\n\x03Get\x12\x16.v1.WorkflowGetRequest\x1a\x17.v1.WorkflowGetResponse\"(\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x16\xaa\xf3\xb3\x07\x11/v1/workflow/{id}\x12h\n\x06\x44\x65lete\x12\x19.v1.WorkflowDeleteRequest\x1a\x1a.v1.WorkflowDeleteResponse\"\'\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x12\xaa\xf3\xb3\x07\r/v1/workflows\x12\x65\n\x06Update\x12\x19.v1.WorkflowUpdateRequest\x1a\x1a.v1.WorkflowUpdateResponse\"$\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x12\xaa\xf3\xb3\x07\r/v1/workflows\x12_\n\x04List\x12\x17.v1.WorkflowListRequest\x1a\x18.v1.WorkflowListResponse\"$\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x12\xaa\xf3\xb3\x07\r/v1/workflows\x1a)\xca\xf9\xb3\x07\r\xc2\xf9\xb3\x07\x08Workflow\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03\x61w-\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42\x65\n\x19\x63om.strongdm.api.plumbingB\x11WorkflowsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_WORKFLOWCREATEREQUEST = DESCRIPTOR.message_types_by_name['WorkflowCreateRequest']
_WORKFLOWCREATERESPONSE = DESCRIPTOR.message_types_by_name['WorkflowCreateResponse']
_WORKFLOWGETREQUEST = DESCRIPTOR.message_types_by_name['WorkflowGetRequest']
_WORKFLOWGETRESPONSE = DESCRIPTOR.message_types_by_name['WorkflowGetResponse']
_WORKFLOWUPDATEREQUEST = DESCRIPTOR.message_types_by_name['WorkflowUpdateRequest']
_WORKFLOWUPDATERESPONSE = DESCRIPTOR.message_types_by_name['WorkflowUpdateResponse']
_WORKFLOWDELETEREQUEST = DESCRIPTOR.message_types_by_name['WorkflowDeleteRequest']
_WORKFLOWDELETERESPONSE = DESCRIPTOR.message_types_by_name['WorkflowDeleteResponse']
_WORKFLOWLISTREQUEST = DESCRIPTOR.message_types_by_name['WorkflowListRequest']
_WORKFLOWLISTRESPONSE = DESCRIPTOR.message_types_by_name['WorkflowListResponse']
_WORKFLOW = DESCRIPTOR.message_types_by_name['Workflow']
WorkflowCreateRequest = _reflection.GeneratedProtocolMessageType('WorkflowCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWCREATEREQUEST,
  '__module__' : 'workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowCreateRequest)
  })
_sym_db.RegisterMessage(WorkflowCreateRequest)

WorkflowCreateResponse = _reflection.GeneratedProtocolMessageType('WorkflowCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWCREATERESPONSE,
  '__module__' : 'workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowCreateResponse)
  })
_sym_db.RegisterMessage(WorkflowCreateResponse)

WorkflowGetRequest = _reflection.GeneratedProtocolMessageType('WorkflowGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWGETREQUEST,
  '__module__' : 'workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowGetRequest)
  })
_sym_db.RegisterMessage(WorkflowGetRequest)

WorkflowGetResponse = _reflection.GeneratedProtocolMessageType('WorkflowGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWGETRESPONSE,
  '__module__' : 'workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowGetResponse)
  })
_sym_db.RegisterMessage(WorkflowGetResponse)

WorkflowUpdateRequest = _reflection.GeneratedProtocolMessageType('WorkflowUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWUPDATEREQUEST,
  '__module__' : 'workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowUpdateRequest)
  })
_sym_db.RegisterMessage(WorkflowUpdateRequest)

WorkflowUpdateResponse = _reflection.GeneratedProtocolMessageType('WorkflowUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWUPDATERESPONSE,
  '__module__' : 'workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowUpdateResponse)
  })
_sym_db.RegisterMessage(WorkflowUpdateResponse)

WorkflowDeleteRequest = _reflection.GeneratedProtocolMessageType('WorkflowDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWDELETEREQUEST,
  '__module__' : 'workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowDeleteRequest)
  })
_sym_db.RegisterMessage(WorkflowDeleteRequest)

WorkflowDeleteResponse = _reflection.GeneratedProtocolMessageType('WorkflowDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWDELETERESPONSE,
  '__module__' : 'workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowDeleteResponse)
  })
_sym_db.RegisterMessage(WorkflowDeleteResponse)

WorkflowListRequest = _reflection.GeneratedProtocolMessageType('WorkflowListRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWLISTREQUEST,
  '__module__' : 'workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowListRequest)
  })
_sym_db.RegisterMessage(WorkflowListRequest)

WorkflowListResponse = _reflection.GeneratedProtocolMessageType('WorkflowListResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWLISTRESPONSE,
  '__module__' : 'workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowListResponse)
  })
_sym_db.RegisterMessage(WorkflowListResponse)

Workflow = _reflection.GeneratedProtocolMessageType('Workflow', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOW,
  '__module__' : 'workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.Workflow)
  })
_sym_db.RegisterMessage(Workflow)

_WORKFLOWS = DESCRIPTOR.services_by_name['Workflows']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\021WorkflowsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _WORKFLOWCREATEREQUEST.fields_by_name['workflow']._options = None
  _WORKFLOWCREATEREQUEST.fields_by_name['workflow']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWCREATERESPONSE.fields_by_name['workflow']._options = None
  _WORKFLOWCREATERESPONSE.fields_by_name['workflow']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _WORKFLOWCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _WORKFLOWCREATERESPONSE._options = None
  _WORKFLOWCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWGETREQUEST.fields_by_name['id']._options = None
  _WORKFLOWGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWGETRESPONSE.fields_by_name['meta']._options = None
  _WORKFLOWGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWGETRESPONSE.fields_by_name['workflow']._options = None
  _WORKFLOWGETRESPONSE.fields_by_name['workflow']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWGETRESPONSE.fields_by_name['rate_limit']._options = None
  _WORKFLOWGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _WORKFLOWGETRESPONSE._options = None
  _WORKFLOWGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWUPDATEREQUEST.fields_by_name['workflow']._options = None
  _WORKFLOWUPDATEREQUEST.fields_by_name['workflow']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWUPDATERESPONSE.fields_by_name['workflow']._options = None
  _WORKFLOWUPDATERESPONSE.fields_by_name['workflow']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _WORKFLOWUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _WORKFLOWUPDATERESPONSE._options = None
  _WORKFLOWUPDATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWDELETEREQUEST.fields_by_name['id']._options = None
  _WORKFLOWDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWDELETERESPONSE.fields_by_name['id']._options = None
  _WORKFLOWDELETERESPONSE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _WORKFLOWDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _WORKFLOWDELETERESPONSE._options = None
  _WORKFLOWDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWLISTREQUEST.fields_by_name['filter']._options = None
  _WORKFLOWLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWLISTRESPONSE.fields_by_name['workflows']._options = None
  _WORKFLOWLISTRESPONSE.fields_by_name['workflows']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _WORKFLOWLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _WORKFLOWLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _WORKFLOWLISTRESPONSE._options = None
  _WORKFLOWLISTRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOW.fields_by_name['id']._options = None
  _WORKFLOW.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOW.fields_by_name['name']._options = None
  _WORKFLOW.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _WORKFLOW.fields_by_name['description']._options = None
  _WORKFLOW.fields_by_name['description']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOW.fields_by_name['weight']._options = None
  _WORKFLOW.fields_by_name['weight']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\320\364\263\007\001'
  _WORKFLOW.fields_by_name['auto_grant']._options = None
  _WORKFLOW.fields_by_name['auto_grant']._serialized_options = b'\030\001\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOW.fields_by_name['enabled']._options = None
  _WORKFLOW.fields_by_name['enabled']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOW.fields_by_name['requires_reason']._options = None
  _WORKFLOW.fields_by_name['requires_reason']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _WORKFLOW.fields_by_name['access_request_max_duration']._options = None
  _WORKFLOW.fields_by_name['access_request_max_duration']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOW.fields_by_name['access_request_fixed_duration']._options = None
  _WORKFLOW.fields_by_name['access_request_fixed_duration']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOW.fields_by_name['access_rules']._options = None
  _WORKFLOW.fields_by_name['access_rules']._serialized_options = b'\362\370\263\007\325\001\260\363\263\007\001\312\363\263\007\251\001\352\363\263\007\014access_rules\362\363\263\007\021\n\002go\022\013AccessRules\362\363\263\007\031\n\ngo_private\022\013AccessRules\362\363\263\007\033\n\014go_terraform\022\013AccessRules\362\363\263\007\030\n\004java\022\020List<AccessRule>\362\363\263\007\"\n\014json_gateway\022\022models.AccessRules\272\364\263\007\027accessRulesDiffSuppress\320\364\263\007\001'
  _WORKFLOW.fields_by_name['approval_flow_id']._options = None
  _WORKFLOW.fields_by_name['approval_flow_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOW._options = None
  _WORKFLOW._serialized_options = b'\372\370\263\007_\250\363\263\007\001\302\363\263\007O\242\363\263\007!tf_examples/workflow_resource.txt\252\363\263\007$tf_examples/workflow_data_source.txt\322\363\263\007\001*'
  _WORKFLOWS._options = None
  _WORKFLOWS._serialized_options = b'\312\371\263\007\r\302\371\263\007\010Workflow\312\371\263\007\010\322\371\263\007\003aw-\312\371\263\007\005\350\371\263\007\001'
  _WORKFLOWS.methods_by_name['Create']._options = None
  _WORKFLOWS.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\022\252\363\263\007\r/v1/workflows'
  _WORKFLOWS.methods_by_name['Get']._options = None
  _WORKFLOWS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\026\252\363\263\007\021/v1/workflow/{id}'
  _WORKFLOWS.methods_by_name['Delete']._options = None
  _WORKFLOWS.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\022\252\363\263\007\r/v1/workflows'
  _WORKFLOWS.methods_by_name['Update']._options = None
  _WORKFLOWS.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\022\252\363\263\007\r/v1/workflows'
  _WORKFLOWS.methods_by_name['List']._options = None
  _WORKFLOWS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\022\252\363\263\007\r/v1/workflows'
  _WORKFLOWCREATEREQUEST._serialized_start=82
  _WORKFLOWCREATEREQUEST._serialized_end=190
  _WORKFLOWCREATERESPONSE._serialized_start=193
  _WORKFLOWCREATERESPONSE._serialized_end=404
  _WORKFLOWGETREQUEST._serialized_start=406
  _WORKFLOWGETREQUEST._serialized_end=488
  _WORKFLOWGETRESPONSE._serialized_start=491
  _WORKFLOWGETRESPONSE._serialized_end=708
  _WORKFLOWUPDATEREQUEST._serialized_start=710
  _WORKFLOWUPDATEREQUEST._serialized_end=818
  _WORKFLOWUPDATERESPONSE._serialized_start=821
  _WORKFLOWUPDATERESPONSE._serialized_end=1032
  _WORKFLOWDELETEREQUEST._serialized_start=1034
  _WORKFLOWDELETEREQUEST._serialized_end=1122
  _WORKFLOWDELETERESPONSE._serialized_start=1125
  _WORKFLOWDELETERESPONSE._serialized_end=1316
  _WORKFLOWLISTREQUEST._serialized_start=1318
  _WORKFLOWLISTREQUEST._serialized_end=1406
  _WORKFLOWLISTRESPONSE._serialized_start=1409
  _WORKFLOWLISTRESPONSE._serialized_end=1617
  _WORKFLOW._serialized_start=1620
  _WORKFLOW._serialized_end=2405
  _WORKFLOWS._serialized_start=2408
  _WORKFLOWS._serialized_end=2970
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import workflows_pb2 as workflows__pb2


class WorkflowsStub(object):
    """Workflows are the collection of rules that define the resources to which access can be requested,
    the users that can request that access, and the mechanism for approving those requests which can either
    be automatic approval or a set of users authorized to approve the requests.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/v1.Workflows/Create',
                request_serializer=workflows__pb2.WorkflowCreateRequest.SerializeToString,
                response_deserializer=workflows__pb2.WorkflowCreateResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/v1.Workflows/Get',
                request_serializer=workflows__pb2.WorkflowGetRequest.SerializeToString,
                response_deserializer=workflows__pb2.WorkflowGetResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/v1.Workflows/Delete',
                request_serializer=workflows__pb2.WorkflowDeleteRequest.SerializeToString,
                response_deserializer=workflows__pb2.WorkflowDeleteResponse.FromString,
                )
        self.Update = channel.unary_unary(
                '/v1.Workflows/Update',
                request_serializer=workflows__pb2.WorkflowUpdateRequest.SerializeToString,
                response_deserializer=workflows__pb2.WorkflowUpdateResponse.FromString,
                )
        self.List = channel.unary_unary(
                '/v1.Workflows/List',
                request_serializer=workflows__pb2.WorkflowListRequest.SerializeToString,
                response_deserializer=workflows__pb2.WorkflowListResponse.FromString,
                )


class WorkflowsServicer(object):
    """Workflows are the collection of rules that define the resources to which access can be requested,
    the users that can request that access, and the mechanism for approving those requests which can either
    be automatic approval or a set of users authorized to approve the requests.
    """

    def Create(self, request, context):
        """Create creates a new workflow and requires a name for the workflow.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Get reads one workflow by ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete deletes an existing workflow.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Update updates an existing workflow.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Lists existing workflows.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkflowsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=workflows__pb2.WorkflowCreateRequest.FromString,
                    response_serializer=workflows__pb2.WorkflowCreateResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=workflows__pb2.WorkflowGetRequest.FromString,
                    response_serializer=workflows__pb2.WorkflowGetResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=workflows__pb2.WorkflowDeleteRequest.FromString,
                    response_serializer=workflows__pb2.WorkflowDeleteResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=workflows__pb2.WorkflowUpdateRequest.FromString,
                    response_serializer=workflows__pb2.WorkflowUpdateResponse.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=workflows__pb2.WorkflowListRequest.FromString,
                    response_serializer=workflows__pb2.WorkflowListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'v1.Workflows', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Workflows(object):
    """Workflows are the collection of rules that define the resources to which access can be requested,
    the users that can request that access, and the mechanism for approving those requests which can either
    be automatic approval or a set of users authorized to approve the requests.
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.Workflows/Create',
            workflows__pb2.WorkflowCreateRequest.SerializeToString,
            workflows__pb2.WorkflowCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.Workflows/Get',
            workflows__pb2.WorkflowGetRequest.SerializeToString,
            workflows__pb2.WorkflowGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.Workflows/Delete',
            workflows__pb2.WorkflowDeleteRequest.SerializeToString,
            workflows__pb2.WorkflowDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.Workflows/Update',
            workflows__pb2.WorkflowUpdateRequest.SerializeToString,
            workflows__pb2.WorkflowUpdateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.Workflows/List',
            workflows__pb2.WorkflowListRequest.SerializeToString,
            workflows__pb2.WorkflowListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: approval_workflow_approvers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!approval_workflow_approvers.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"\x9e\x01\n%ApprovalWorkflowApproverCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12L\n\x1a\x61pproval_workflow_approver\x18\x02 \x01(\x0b\x32\x1c.v1.ApprovalWorkflowApproverB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\x85\x02\n&ApprovalWorkflowApproverCreateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12L\n\x1a\x61pproval_workflow_approver\x18\x02 \x01(\x0b\x32\x1c.v1.ApprovalWorkflowApproverB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"b\n\"ApprovalWorkflowApproverGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\x8b\x02\n#ApprovalWorkflowApproverGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12L\n\x1a\x61pproval_workflow_approver\x18\x02 \x01(\x0b\x32\x1c.v1.ApprovalWorkflowApproverB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"h\n%ApprovalWorkflowApproverDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xcf\x01\n&ApprovalWorkflowApproverDeleteResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"h\n#ApprovalWorkflowApproverListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\x82\x02\n$ApprovalWorkflowApproverListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12M\n\x1b\x61pproval_workflow_approvers\x18\x02 \x03(\x0b\x32\x1c.v1.ApprovalWorkflowApproverB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xe9\x02\n\x18\x41pprovalWorkflowApprover\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12)\n\x10\x61pproval_flow_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12)\n\x10\x61pproval_step_id\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1e\n\naccount_id\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1b\n\x07role_id\x18\x05 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12I\n\treference\x18\x06 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x13!terraform-provider\xb2\xf4\xb3\x07\x04!cli\x12+\n\x08group_id\x18\x07 \x01(\tB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private:*\x18\x01\xfa\xf8\xb3\x07#\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x13!terraform-provider2\xe3\x05\n\x19\x41pprovalWorkflowApprovers\x12\x98\x01\n\x06\x43reate\x12).v1.ApprovalWorkflowApproverCreateRequest\x1a*.v1.ApprovalWorkflowApproverCreateResponse\"7\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07$\xaa\xf3\xb3\x07\x1f/v1/approval-workflow-approvers\x12\x92\x01\n\x03Get\x12&.v1.ApprovalWorkflowApproverGetRequest\x1a\'.v1.ApprovalWorkflowApproverGetResponse\":\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07(\xaa\xf3\xb3\x07#/v1/approval-workflow-approver/{id}\x12\x9a\x01\n\x06\x44\x65lete\x12).v1.ApprovalWorkflowApproverDeleteRequest\x1a*.v1.ApprovalWorkflowApproverDeleteResponse\"9\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07$\xaa\xf3\xb3\x07\x1f/v1/approval-workflow-approvers\x12\x91\x01\n\x04List\x12\'.v1.ApprovalWorkflowApproverListRequest\x1a(.v1.ApprovalWorkflowApproverListResponse\"6\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07$\xaa\xf3\xb3\x07\x1f/v1/approval-workflow-approvers\x1a\x65\x88\x02\x01\xca\xf9\xb3\x07\x1d\xc2\xf9\xb3\x07\x18\x41pprovalWorkflowApprover\xca\xf9\xb3\x07\t\xd2\xf9\xb3\x07\x04\x61\x66\x61-\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-providerBu\n\x19\x63om.strongdm.api.plumbingB!ApprovalWorkflowApproversPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_APPROVALWORKFLOWAPPROVERCREATEREQUEST = DESCRIPTOR.message_types_by_name['ApprovalWorkflowApproverCreateRequest']
_APPROVALWORKFLOWAPPROVERCREATERESPONSE = DESCRIPTOR.message_types_by_name['ApprovalWorkflowApproverCreateResponse']
_APPROVALWORKFLOWAPPROVERGETREQUEST = DESCRIPTOR.message_types_by_name['ApprovalWorkflowApproverGetRequest']
_APPROVALWORKFLOWAPPROVERGETRESPONSE = DESCRIPTOR.message_types_by_name['ApprovalWorkflowApproverGetResponse']
_APPROVALWORKFLOWAPPROVERDELETEREQUEST = DESCRIPTOR.message_types_by_name['ApprovalWorkflowApproverDeleteRequest']
_APPROVALWORKFLOWAPPROVERDELETERESPONSE = DESCRIPTOR.message_types_by_name['ApprovalWorkflowApproverDeleteResponse']
_APPROVALWORKFLOWAPPROVERLISTREQUEST = DESCRIPTOR.message_types_by_name['ApprovalWorkflowApproverListRequest']
_APPROVALWORKFLOWAPPROVERLISTRESPONSE = DESCRIPTOR.message_types_by_name['ApprovalWorkflowApproverListResponse']
_APPROVALWORKFLOWAPPROVER = DESCRIPTOR.message_types_by_name['ApprovalWorkflowApprover']
ApprovalWorkflowApproverCreateRequest = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowApproverCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWAPPROVERCREATEREQUEST,
  '__module__' : 'approval_workflow_approvers_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowApproverCreateRequest)
  })
_sym_db.RegisterMessage(ApprovalWorkflowApproverCreateRequest)

ApprovalWorkflowApproverCreateResponse = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowApproverCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWAPPROVERCREATERESPONSE,
  '__module__' : 'approval_workflow_approvers_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowApproverCreateResponse)
  })
_sym_db.RegisterMessage(ApprovalWorkflowApproverCreateResponse)

ApprovalWorkflowApproverGetRequest = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowApproverGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWAPPROVERGETREQUEST,
  '__module__' : 'approval_workflow_approvers_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowApproverGetRequest)
  })
_sym_db.RegisterMessage(ApprovalWorkflowApproverGetRequest)

ApprovalWorkflowApproverGetResponse = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowApproverGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWAPPROVERGETRESPONSE,
  '__module__' : 'approval_workflow_approvers_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowApproverGetResponse)
  })
_sym_db.RegisterMessage(ApprovalWorkflowApproverGetResponse)

ApprovalWorkflowApproverDeleteRequest = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowApproverDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWAPPROVERDELETEREQUEST,
  '__module__' : 'approval_workflow_approvers_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowApproverDeleteRequest)
  })
_sym_db.RegisterMessage(ApprovalWorkflowApproverDeleteRequest)

ApprovalWorkflowApproverDeleteResponse = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowApproverDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWAPPROVERDELETERESPONSE,
  '__module__' : 'approval_workflow_approvers_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowApproverDeleteResponse)
  })
_sym_db.RegisterMessage(ApprovalWorkflowApproverDeleteResponse)

ApprovalWorkflowApproverListRequest = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowApproverListRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWAPPROVERLISTREQUEST,
  '__module__' : 'approval_workflow_approvers_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowApproverListRequest)
  })
_sym_db.RegisterMessage(ApprovalWorkflowApproverListRequest)

ApprovalWorkflowApproverListResponse = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowApproverListResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWAPPROVERLISTRESPONSE,
  '__module__' : 'approval_workflow_approvers_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowApproverListResponse)
  })
_sym_db.RegisterMessage(ApprovalWorkflowApproverListResponse)

ApprovalWorkflowApprover = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowApprover', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWAPPROVER,
  '__module__' : 'approval_workflow_approvers_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowApprover)
  })
_sym_db.RegisterMessage(ApprovalWorkflowApprover)

_APPROVALWORKFLOWAPPROVERS = DESCRIPTOR.services_by_name['ApprovalWorkflowApprovers']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB!ApprovalWorkflowApproversPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _APPROVALWORKFLOWAPPROVERCREATEREQUEST.fields_by_name['approval_workflow_approver']._options = None
  _APPROVALWORKFLOWAPPROVERCREATEREQUEST.fields_by_name['approval_workflow_approver']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWAPPROVERCREATERESPONSE.fields_by_name['approval_workflow_approver']._options = None
  _APPROVALWORKFLOWAPPROVERCREATERESPONSE.fields_by_name['approval_workflow_approver']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWAPPROVERCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _APPROVALWORKFLOWAPPROVERCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _APPROVALWORKFLOWAPPROVERCREATERESPONSE._options = None
  _APPROVALWORKFLOWAPPROVERCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _APPROVALWORKFLOWAPPROVERGETREQUEST.fields_by_name['id']._options = None
  _APPROVALWORKFLOWAPPROVERGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWAPPROVERGETRESPONSE.fields_by_name['meta']._options = None
  _APPROVALWORKFLOWAPPROVERGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWAPPROVERGETRESPONSE.fields_by_name['approval_workflow_approver']._options = None
  _APPROVALWORKFLOWAPPROVERGETRESPONSE.fields_by_name['approval_workflow_approver']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWAPPROVERGETRESPONSE.fields_by_name['rate_limit']._options = None
  _APPROVALWORKFLOWAPPROVERGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _APPROVALWORKFLOWAPPROVERGETRESPONSE._options = None
  _APPROVALWORKFLOWAPPROVERGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _APPROVALWORKFLOWAPPROVERDELETEREQUEST.fields_by_name['id']._options = None
  _APPROVALWORKFLOWAPPROVERDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWAPPROVERDELETERESPONSE.fields_by_name['id']._options = None
  _APPROVALWORKFLOWAPPROVERDELETERESPONSE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWAPPROVERDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _APPROVALWORKFLOWAPPROVERDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _APPROVALWORKFLOWAPPROVERDELETERESPONSE._options = None
  _APPROVALWORKFLOWAPPROVERDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _APPROVALWORKFLOWAPPROVERLISTREQUEST.fields_by_name['filter']._options = None
  _APPROVALWORKFLOWAPPROVERLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWAPPROVERLISTRESPONSE.fields_by_name['approval_workflow_approvers']._options = None
  _APPROVALWORKFLOWAPPROVERLISTRESPONSE.fields_by_name['approval_workflow_approvers']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _APPROVALWORKFLOWAPPROVERLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _APPROVALWORKFLOWAPPROVERLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _APPROVALWORKFLOWAPPROVERLISTRESPONSE._options = None
  _APPROVALWORKFLOWAPPROVERLISTRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _APPROVALWORKFLOWAPPROVER.fields_by_name['id']._options = None
  _APPROVALWORKFLOWAPPROVER.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWAPPROVER.fields_by_name['approval_flow_id']._options = None
  _APPROVALWORKFLOWAPPROVER.fields_by_name['approval_flow_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _APPROVALWORKFLOWAPPROVER.fields_by_name['approval_step_id']._options = None
  _APPROVALWORKFLOWAPPROVER.fields_by_name['approval_step_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _APPROVALWORKFLOWAPPROVER.fields_by_name['account_id']._options = None
  _APPROVALWORKFLOWAPPROVER.fields_by_name['account_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWAPPROVER.fields_by_name['role_id']._options = None
  _APPROVALWORKFLOWAPPROVER.fields_by_name['role_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWAPPROVER.fields_by_name['reference']._options = None
  _APPROVALWORKFLOWAPPROVER.fields_by_name['reference']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\023!terraform-provider\262\364\263\007\004!cli'
  _APPROVALWORKFLOWAPPROVER.fields_by_name['group_id']._options = None
  _APPROVALWORKFLOWAPPROVER.fields_by_name['group_id']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _APPROVALWORKFLOWAPPROVER._options = None
  _APPROVALWORKFLOWAPPROVER._serialized_options = b'\030\001\372\370\263\007#\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\023!terraform-provider'
  _APPROVALWORKFLOWAPPROVERS._options = None
  _APPROVALWORKFLOWAPPROVERS._serialized_options = b'\210\002\001\312\371\263\007\035\302\371\263\007\030ApprovalWorkflowApprover\312\371\263\007\t\322\371\263\007\004afa-\312\371\263\007\005\350\371\263\007\001\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider'
  _APPROVALWORKFLOWAPPROVERS.methods_by_name['Create']._options = None
  _APPROVALWORKFLOWAPPROVERS.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007$\252\363\263\007\037/v1/approval-workflow-approvers'
  _APPROVALWORKFLOWAPPROVERS.methods_by_name['Get']._options = None
  _APPROVALWORKFLOWAPPROVERS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007(\252\363\263\007#/v1/approval-workflow-approver/{id}'
  _APPROVALWORKFLOWAPPROVERS.methods_by_name['Delete']._options = None
  _APPROVALWORKFLOWAPPROVERS.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007$\252\363\263\007\037/v1/approval-workflow-approvers'
  _APPROVALWORKFLOWAPPROVERS.methods_by_name['List']._options = None
  _APPROVALWORKFLOWAPPROVERS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007$\252\363\263\007\037/v1/approval-workflow-approvers'
  _APPROVALWORKFLOWAPPROVERCREATEREQUEST._serialized_start=69
  _APPROVALWORKFLOWAPPROVERCREATEREQUEST._serialized_end=227
  _APPROVALWORKFLOWAPPROVERCREATERESPONSE._serialized_start=230
  _APPROVALWORKFLOWAPPROVERCREATERESPONSE._serialized_end=491
  _APPROVALWORKFLOWAPPROVERGETREQUEST._serialized_start=493
  _APPROVALWORKFLOWAPPROVERGETREQUEST._serialized_end=591
  _APPROVALWORKFLOWAPPROVERGETRESPONSE._serialized_start=594
  _APPROVALWORKFLOWAPPROVERGETRESPONSE._serialized_end=861
  _APPROVALWORKFLOWAPPROVERDELETEREQUEST._serialized_start=863
  _APPROVALWORKFLOWAPPROVERDELETEREQUEST._serialized_end=967
  _APPROVALWORKFLOWAPPROVERDELETERESPONSE._serialized_start=970
  _APPROVALWORKFLOWAPPROVERDELETERESPONSE._serialized_end=1177
  _APPROVALWORKFLOWAPPROVERLISTREQUEST._serialized_start=1179
  _APPROVALWORKFLOWAPPROVERLISTREQUEST._serialized_end=1283
  _APPROVALWORKFLOWAPPROVERLISTRESPONSE._serialized_start=1286
  _APPROVALWORKFLOWAPPROVERLISTRESPONSE._serialized_end=1544
  _APPROVALWORKFLOWAPPROVER._serialized_start=1547
  _APPROVALWORKFLOWAPPROVER._serialized_end=1908
  _APPROVALWORKFLOWAPPROVERS._serialized_start=1911
  _APPROVALWORKFLOWAPPROVERS._serialized_end=2650
# @@protoc_insertion_point(module_scope)
